QuDataBase - Qudas 0.2.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# QuDataBase

量子データのベースとなるクラスです。

class qudas.qudata.QuDataBase(data: Dict[str, Any] | None = None)

  Bases: `ABC`

  __abstractmethods__ = frozenset({})
  __dict__ = mappingproxy({'__module__': 'qudas.qudata.qudata_base', '__init__': <function QuDataBase.__init__>, '__dict__': <attribute '__dict__' of 'QuDataBase' objects>, '__weakref__': <attribute '__weakref__' of 'QuDataBase' objects>, '__doc__': None, '__abstractmethods__': frozenset(), '_abc_impl': <_abc_data object>, '__annotations__': {}})
  __init__(data: Dict[str, Any] | None = None)

    初期データを格納する抽象クラス。

    Parameters:

      data (dict, optional) – 入力または出力データ。デフォルトはNone。

  __module__ = 'qudas.qudata.qudata_base'
  __weakref__

    list of weak references to the object (if defined)